@@ -6,6 +6,7 @@ import (
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
@@ -17,8 +18,11 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// debugCmd represents the prompt command
-var debugCmd = createDebugCmd()
+// debugCmd represents the debug command
+var (
+	debugCmd  = createDebugCmd()
+	startTime = time.Now()
+)
 
 func init() {
 	RootCmd.AddCommand(debugCmd)
@@ -32,30 +36,28 @@ func createDebugCmd() *cobra.Command {
 		Run: func(_ *cobra.Command, _ []string) {
 			startTime := time.Now()
 
-			log.Enable()
-			log.Debug("debug mode enabled")
-
-			sh := os.Getenv("POSH_SHELL")
-
-			configFile := config.Path(configFlag)
-			cfg, _ := config.Load(configFile, sh, false)
+			log.Enable(plain)
 
 			flags := &runtime.Flags{
-				Config: configFile,
-				Debug:  true,
-				PWD:    pwd,
-				Shell:  sh,
-				Plain:  plain,
+				Debug: true,
+				PWD:   pwd,
+				Shell: shell.GENERIC,
+				Plain: plain,
 			}
 
 			env := &runtime.Terminal{}
 			env.Init(flags)
 
+			cache.Init(os.Getenv("POSH_SHELL"), false)
+
+			_, reload := cache.Get[bool](cache.Session, config.RELOAD)
+			cfg := config.Get(flags.ConfigPath, reload)
+
 			template.Init(env, cfg.Var, cfg.Maps)
 
 			defer func() {
 				template.SaveCache()
-				env.Close()
+				cache.Close()
 			}()
 
 			terminal.Init(shell.GENERIC)
@@ -74,7 +76,6 @@ func createDebugCmd() *cobra.Command {
 	}
 
 	debugCmd.Flags().StringVar(&pwd, "pwd", "", "current working directory")
-	debugCmd.Flags().BoolVarP(&plain, "plain", "p", false, "plain text output (no ANSI)")
 
 	// Deprecated flags, should be kept to avoid breaking CLI integration.
 	debugCmd.Flags().StringVar(&shellName, "shell", "", "the shell to print for")
