@@ -17,6 +17,7 @@ var (
 	toggleArgs = []string{
 		config.UPGRADENOTICE,
 		config.AUTOUPGRADE,
+		config.RELOAD,
 	}
 	toggleUse  = fmt.Sprintf("%%s [%s]", strings.Join(toggleArgs, "|"))
 	toggleLong = strings.Join(append([]string{toggleHelpText}, toggleArgs...), "\n- ")
@@ -44,13 +45,17 @@ func init() {
 
 func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
 	flags := &runtime.Flags{
-		Shell:     shellName,
-		SaveCache: true,
+		Shell: shellName,
 	}
 
 	env := &runtime.Terminal{}
 	env.Init(flags)
-	defer env.Close()
+
+	cache.Init(shellName, true)
+
+	defer func() {
+		cache.Close()
+	}()
 
 	if feature == "" {
 		_ = cmd.Help()
@@ -58,9 +63,9 @@ func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
 	}
 
 	if enable {
-		env.Cache().Set(feature, "true", cache.INFINITE)
+		cache.Set(cache.Device, feature, "true", cache.INFINITE)
 		return
 	}
 
-	env.Cache().Delete(feature)
+	cache.Delete(cache.Device, feature)
 }
