@@ -1,10 +1,16 @@
 package font
 
 import (
+	"encoding/gob"
+
 	"github.com/jandedobbeleer/oh-my-posh/src/dsc"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
+func init() {
+	gob.Register([]*Font{})
+}
+
 type Resource struct {
 	dsc.Resource[*Font]
 }
@@ -18,7 +24,6 @@ func DSC() *Resource {
 }
 
 func (s *Resource) Apply(schema string) error {
-	SetCache(s.Cache)
 	return s.Resource.Apply(schema)
 }
 
