@@ -1,6 +1,7 @@
 package color
 
 import (
+	"encoding/gob"
 	"fmt"
 	"strconv"
 	"strings"
@@ -14,6 +15,10 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
+func init() {
+	gob.Register(Set{})
+}
+
 var TrueColor = true
 
 // String is the interface that wraps ToColor method.
@@ -164,10 +169,8 @@ func (d *Defaults) SetAccentColor(env runtime.Environment, defaultColor Ansi) {
 	defer log.Trace(time.Now())
 
 	// get accent color from session cache first
-	if accent, OK := env.Session().Get("accent_color"); OK {
-		accentColors := &Set{}
-		accentColors.ParseString(accent)
-		d.accent = accentColors
+	if accent, OK := cache.Get[*Set](cache.Device, "accent_color"); OK {
+		d.accent = accent
 		return
 	}
 
@@ -193,7 +196,7 @@ func (d *Defaults) SetAccentColor(env runtime.Environment, defaultColor Ansi) {
 		Background: Ansi(background.String()),
 	}
 
-	env.Session().Set("accent_color", d.accent.String(), cache.INFINITE)
+	cache.Set(cache.Device, "accent_color", d.accent, cache.INFINITE)
 }
 
 type RGB struct {
