@@ -1,9 +1,11 @@
 package config
 
 import (
+	"encoding/gob"
 	"slices"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/color"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
@@ -15,13 +17,22 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 )
 
+func init() {
+	gob.Register(&Config{})
+}
+
 const (
 	JSON string = "json"
 	YAML string = "yaml"
 	TOML string = "toml"
 
+	TML   string = "tml"
+	YML   string = "yml"
+	JSONC string = "jsonc"
+
 	AUTOUPGRADE   = "upgrade"
 	UPGRADENOTICE = "notice"
+	RELOAD        = "reload"
 
 	Version = 3
 )
@@ -49,28 +60,28 @@ type Config struct {
 	ErrorLine               *Segment               `json:"error_line,omitempty" toml:"error_line,omitempty" yaml:"error_line,omitempty"`
 	Maps                    *maps.Config           `json:"maps,omitempty" toml:"maps,omitempty" yaml:"maps,omitempty"`
 	Upgrade                 *upgrade.Config        `json:"upgrade,omitempty" toml:"upgrade,omitempty" yaml:"upgrade,omitempty"`
-	TerminalBackground      color.Ansi             `json:"terminal_background,omitempty" toml:"terminal_background,omitempty" yaml:"terminal_background,omitempty"`
+	Extends                 string                 `json:"extends,omitempty" toml:"extends,omitempty" yaml:"extends,omitempty"`
 	AccentColor             color.Ansi             `json:"accent_color,omitempty" toml:"accent_color,omitempty" yaml:"accent_color,omitempty"`
 	ConsoleTitleTemplate    string                 `json:"console_title_template,omitempty" toml:"console_title_template,omitempty" yaml:"console_title_template,omitempty"`
 	PWD                     string                 `json:"pwd,omitempty" toml:"pwd,omitempty" yaml:"pwd,omitempty"`
 	Source                  string                 `json:"-" toml:"-" yaml:"-"`
 	Format                  string                 `json:"-" toml:"-" yaml:"-"`
-	Extends                 string                 `json:"extends,omitempty" toml:"extends,omitempty" yaml:"extends,omitempty"`
+	TerminalBackground      color.Ansi             `json:"terminal_background,omitempty" toml:"terminal_background,omitempty" yaml:"terminal_background,omitempty"`
 	ToolTipsAction          Action                 `json:"tooltips_action,omitempty" toml:"tooltips_action,omitempty" yaml:"tooltips_action,omitempty"`
-	Cycle                   color.Cycle            `json:"cycle,omitempty" toml:"cycle,omitempty" yaml:"cycle,omitempty"`
-	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
-	Blocks                  []*Block               `json:"blocks,omitempty" toml:"blocks,omitempty" yaml:"blocks,omitempty"`
 	Tooltips                []*Segment             `json:"tooltips,omitempty" toml:"tooltips,omitempty" yaml:"tooltips,omitempty"`
+	Blocks                  []*Block               `json:"blocks,omitempty" toml:"blocks,omitempty" yaml:"blocks,omitempty"`
+	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
+	Cycle                   color.Cycle            `json:"cycle,omitempty" toml:"cycle,omitempty" yaml:"cycle,omitempty"`
 	Version                 int                    `json:"version" toml:"version" yaml:"version"`
-	PatchPwshBleed          bool                   `json:"patch_pwsh_bleed,omitempty" toml:"patch_pwsh_bleed,omitempty" yaml:"patch_pwsh_bleed,omitempty"`
-	MigrateGlyphs           bool                   `json:"-" toml:"-" yaml:"-"`
-	ShellIntegration        bool                   `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
 	EnableCursorPositioning bool                   `json:"enable_cursor_positioning,omitempty" toml:"enable_cursor_positioning,omitempty" yaml:"enable_cursor_positioning,omitempty"`
+	ShellIntegration        bool                   `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
+	MigrateGlyphs           bool                   `json:"-" toml:"-" yaml:"-"`
 	Async                   bool                   `json:"async,omitempty" toml:"async,omitempty" yaml:"async,omitempty"`
 	FinalSpace              bool                   `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
 	UpgradeNotice           bool                   `json:"-" toml:"-" yaml:"-"`
 	updated                 bool
 	extended                bool
+	PatchPwshBleed          bool `json:"patch_pwsh_bleed,omitempty" toml:"patch_pwsh_bleed,omitempty" yaml:"patch_pwsh_bleed,omitempty"`
 	AutoUpgrade             bool `json:"-" toml:"-" yaml:"-"`
 }
 
@@ -84,11 +95,7 @@ func (cfg *Config) getPalette() color.Palette {
 		return cfg.Palette
 	}
 
-	tmpl := &template.Text{
-		Template: cfg.Palettes.Template,
-	}
-
-	key, err := tmpl.Render()
+	key, err := template.Render(cfg.Palettes.Template, nil)
 	if err != nil {
 		return cfg.Palette
 	}
@@ -116,48 +123,53 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 
 	if cfg.Async && slices.Contains(asyncShells, env.Shell()) {
 		log.Debug("async enabled")
-		feats = append(feats, shell.Async)
+		feats |= shell.Async
 	}
 
 	if cfg.TransientPrompt != nil {
 		log.Debug("transient prompt enabled")
-		feats = append(feats, shell.Transient)
+		feats |= shell.Transient
+	}
+
+	unsupportedShells := []string{shell.ELVISH, shell.XONSH}
+	if slices.Contains(unsupportedShells, env.Shell()) {
+		cfg.ShellIntegration = false
 	}
 
 	if cfg.ShellIntegration {
 		log.Debug("shell integration enabled")
-		feats = append(feats, shell.FTCSMarks)
+		feats |= shell.FTCSMarks
 	}
 
 	// do not enable upgrade features when async is enabled
-	if !slices.Contains(feats, shell.Async) {
-		feats = append(feats, cfg.upgradeFeatures(env)...)
+	if feats&shell.Async == 0 {
+		feats |= cfg.upgradeFeatures()
 	}
 
 	if cfg.ErrorLine != nil || cfg.ValidLine != nil {
 		log.Debug("error or valid line enabled")
-		feats = append(feats, shell.LineError)
+		feats |= shell.LineError
 	}
 
 	if len(cfg.Tooltips) > 0 {
 		log.Debug("tooltips enabled")
-		feats = append(feats, shell.Tooltips)
+		feats |= shell.Tooltips
 	}
 
 	if env.Shell() == shell.FISH && cfg.ITermFeatures != nil && cfg.ITermFeatures.Contains(terminal.PromptMark) {
 		log.Debug("prompt mark enabled")
-		feats = append(feats, shell.PromptMark)
+		feats |= shell.PromptMark
 	}
 
 	for i, block := range cfg.Blocks {
 		if (i == 0 && block.Newline) && cfg.EnableCursorPositioning {
 			log.Debug("cursor positioning enabled")
-			feats = append(feats, shell.CursorPositioning)
+			feats |= shell.CursorPositioning
 		}
 
 		if block.Type == RPrompt {
 			log.Debug("rprompt enabled")
-			feats = append(feats, shell.RPrompt)
+			feats |= shell.RPrompt
 		}
 
 		for _, segment := range block.Segments {
@@ -165,7 +177,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 				source := segment.Properties.GetString(segments.Source, segments.FirstMatch)
 				if strings.Contains(source, segments.Pwsh) {
 					log.Debug("azure enabled")
-					feats = append(feats, shell.Azure)
+					feats |= shell.Azure
 				}
 			}
 
@@ -173,7 +185,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 				source := segment.Properties.GetString(segments.Source, segments.Cli)
 				if source == segments.Pwsh {
 					log.Debug("posh-git enabled")
-					feats = append(feats, shell.PoshGit)
+					feats |= shell.PoshGit
 				}
 			}
 		}
@@ -182,34 +194,34 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 	return feats
 }
 
-func (cfg *Config) upgradeFeatures(env runtime.Environment) shell.Features {
-	feats := shell.Features{}
+func (cfg *Config) upgradeFeatures() shell.Features {
+	var feats shell.Features
 
-	if _, OK := env.Cache().Get(upgrade.CACHEKEY); OK && !cfg.Upgrade.Force {
+	if _, OK := cache.Get[string](cache.Device, upgrade.CACHEKEY); OK && !cfg.Upgrade.Force {
 		log.Debug("upgrade cache key found and not forced, skipping upgrade")
 		return feats
 	}
 
 	autoUpgrade := cfg.Upgrade.Auto
-	if _, OK := env.Cache().Get(AUTOUPGRADE); OK {
+	if _, OK := cache.Get[string](cache.Device, AUTOUPGRADE); OK {
 		log.Debug("auto upgrade key found")
 		autoUpgrade = true
 	}
 
 	upgradeNotice := cfg.Upgrade.DisplayNotice
-	if _, OK := env.Cache().Get(UPGRADENOTICE); OK {
+	if _, OK := cache.Get[string](cache.Device, UPGRADENOTICE); OK {
 		log.Debug("upgrade notice key found")
 		upgradeNotice = true
 	}
 
 	if upgradeNotice && !autoUpgrade {
 		log.Debug("notice enabled, no auto upgrade")
-		feats = append(feats, shell.Notice)
+		feats |= shell.Notice
 	}
 
 	if autoUpgrade {
 		log.Debug("auto upgrade enabled")
-		feats = append(feats, shell.Upgrade)
+		feats |= shell.Upgrade
 	}
 
 	return feats
