@@ -1,6 +1,7 @@
 package config
 
 import (
+	"encoding/gob"
 	"errors"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
@@ -22,6 +23,112 @@ type SegmentWriter interface {
 	CacheKey() (string, bool)
 }
 
+func init() {
+	gob.Register(&segments.Angular{})
+	gob.Register(&segments.Argocd{})
+	gob.Register(&segments.Aurelia{})
+	gob.Register(&segments.Aws{})
+	gob.Register(&segments.Az{})
+	gob.Register(&segments.Azd{})
+	gob.Register(&segments.AzFunc{})
+	gob.Register(&segments.Battery{})
+	gob.Register(&segments.Bazel{})
+	gob.Register(&segments.Brewfather{})
+	gob.Register(&segments.Buf{})
+	gob.Register(&segments.Bun{})
+	gob.Register(&segments.CarbonIntensity{})
+	gob.Register(&segments.Cds{})
+	gob.Register(&segments.Cf{})
+	gob.Register(&segments.CfTarget{})
+	gob.Register(&segments.Cmake{})
+	gob.Register(&segments.Cmd{})
+	gob.Register(&segments.Connection{})
+	gob.Register(&segments.Crystal{})
+	gob.Register(&segments.Dart{})
+	gob.Register(&segments.Deno{})
+	gob.Register(&segments.Docker{})
+	gob.Register(&segments.Dotnet{})
+	gob.Register(&segments.Elixir{})
+	gob.Register(&segments.Executiontime{})
+	gob.Register(&segments.Status{})
+	gob.Register(&segments.Firebase{})
+	gob.Register(&segments.Flutter{})
+	gob.Register(&segments.Fortran{})
+	gob.Register(&segments.Fossil{})
+	gob.Register(&segments.Gcp{})
+	gob.Register(&segments.Git{})
+	gob.Register(&segments.GitVersion{})
+	gob.Register(&segments.Golang{})
+	gob.Register(&segments.Haskell{})
+	gob.Register(&segments.Helm{})
+	gob.Register(&segments.IPify{})
+	gob.Register(&segments.Java{})
+	gob.Register(&segments.HTTP{})
+	gob.Register(&segments.Jujutsu{})
+	gob.Register(&segments.Julia{})
+	gob.Register(&segments.Kotlin{})
+	gob.Register(&segments.Kubectl{})
+	gob.Register(&segments.LastFM{})
+	gob.Register(&segments.Lua{})
+	gob.Register(&segments.Mercurial{})
+	gob.Register(&segments.Mojo{})
+	gob.Register(&segments.Mvn{})
+	gob.Register(&segments.Nba{})
+	gob.Register(&segments.Nbgv{})
+	gob.Register(&segments.Nightscout{})
+	gob.Register(&segments.NixShell{})
+	gob.Register(&segments.Nim{})
+	gob.Register(&segments.Node{})
+	gob.Register(&segments.Npm{})
+	gob.Register(&segments.Nx{})
+	gob.Register(&segments.OCaml{})
+	gob.Register(&segments.Os{})
+	gob.Register(&segments.Owm{})
+	gob.Register(&segments.Path{})
+	gob.Register(&segments.Perl{})
+	gob.Register(&segments.Php{})
+	gob.Register(&segments.Plastic{})
+	gob.Register(&segments.Pnpm{})
+	gob.Register(&segments.Project{})
+	gob.Register(&segments.Pulumi{})
+	gob.Register(&segments.Python{})
+	gob.Register(&segments.Quasar{})
+	gob.Register(&segments.R{})
+	gob.Register(&segments.React{})
+	gob.Register(&segments.Root{})
+	gob.Register(&segments.Ruby{})
+	gob.Register(&segments.Rust{})
+	gob.Register(&segments.Sapling{})
+	gob.Register(&segments.Session{})
+	gob.Register(&segments.Shell{})
+	gob.Register(&segments.Sitecore{})
+	gob.Register(&segments.Spotify{})
+	gob.Register(&segments.Status{})
+	gob.Register(&segments.Strava{})
+	gob.Register(&segments.Svelte{})
+	gob.Register(&segments.Svn{})
+	gob.Register(&segments.Swift{})
+	gob.Register(&segments.SystemInfo{})
+	gob.Register(&segments.TalosCTL{})
+	gob.Register(&segments.Tauri{})
+	gob.Register(&segments.Terraform{})
+	gob.Register(&segments.Text{})
+	gob.Register(&segments.Time{})
+	gob.Register(&segments.UI5Tooling{})
+	gob.Register(&segments.Umbraco{})
+	gob.Register(&segments.Unity{})
+	gob.Register(&segments.Upgrade{})
+	gob.Register(&segments.V{})
+	gob.Register(&segments.Vala{})
+	gob.Register(&segments.Wakatime{})
+	gob.Register(&segments.WindowsRegistry{})
+	gob.Register(&segments.Withings{})
+	gob.Register(&segments.XMake{})
+	gob.Register(&segments.Yarn{})
+	gob.Register(&segments.Ytm{})
+	gob.Register(&segments.Zig{})
+}
+
 const (
 	// Plain writes it without ornaments
 	Plain SegmentStyle = "plain"
