@@ -4,11 +4,10 @@ import (
 	"io"
 	"io/fs"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/battery"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
 
-	disk "github.com/shirou/gopsutil/v3/disk"
+	disk "github.com/shirou/gopsutil/v4/disk"
 )
 
 const (
@@ -58,9 +57,6 @@ type Environment interface {
 	IsCygwin() bool
 	StackCount() int
 	TerminalWidth() (int, error)
-	Cache() cache.Cache
-	Session() cache.Cache
-	Close()
 	Logs() string
 	InWSLSharedDrive() bool
 	ConvertToLinuxPath(input string) string
@@ -73,13 +69,13 @@ type Environment interface {
 type Flags struct {
 	PSWD          string
 	PipeStatus    string
-	Config        string
+	ConfigPath    string
+	ConfigHash    string
 	Shell         string
 	ShellVersion  string
 	PWD           string
 	AbsolutePWD   string
 	Type          string
-	ConfigHash    string
 	PromptCount   int
 	Column        int
 	TerminalWidth int
@@ -92,13 +88,13 @@ type Flags struct {
 	Debug         bool
 	Cleared       bool
 	NoExitCode    bool
-	SaveCache     bool
 	Init          bool
 	Migrate       bool
 	Eval          bool
 	Escape        bool
 	IsPrimary     bool
 	Plain         bool
+	Force         bool
 }
 
 type CommandError struct {
