@@ -5,7 +5,6 @@ import (
 	"io/fs"
 	"time"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/battery"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
@@ -182,16 +181,6 @@ func (env *Environment) CachePath() string {
 	return args.String(0)
 }
 
-func (env *Environment) Cache() cache.Cache {
-	args := env.Called()
-	return args.Get(0).(cache.Cache)
-}
-
-func (env *Environment) Session() cache.Cache {
-	args := env.Called()
-	return args.Get(0).(cache.Cache)
-}
-
 func (env *Environment) Close() {
 	_ = env.Called()
 }
