@@ -4,6 +4,8 @@ import (
 	"encoding/json"
 	"path/filepath"
 	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
 type Azd struct {
@@ -32,8 +34,8 @@ func (t *Azd) Enabled() bool {
 		}
 	}
 
-	if len(parentFilePath) == 0 {
-		t.env.Debug("no .azure folder found in parent directories")
+	if parentFilePath == "" {
+		log.Debug("no .azure folder found in parent directories")
 		return false
 	}
 
@@ -54,7 +56,7 @@ func (t *Azd) Enabled() bool {
 }
 
 func (t *Azd) TryReadConfigJSON(file string) bool {
-	if len(file) == 0 {
+	if file == "" {
 		return false
 	}
 
