@@ -2,15 +2,14 @@ package segments
 
 import (
 	"path/filepath"
+	"slices"
 	"testing"
 
-	cache_ "github.com/jandedobbeleer/oh-my-posh/src/cache/mock"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
-	mock_ "github.com/stretchr/testify/mock"
 )
 
 const (
@@ -33,12 +32,7 @@ type languageArgs struct {
 }
 
 func (l *languageArgs) hasvalue(value string, list []string) bool {
-	for _, element := range list {
-		if element == value {
-			return true
-		}
-	}
-	return false
+	return slices.Contains(list, value)
 }
 
 func bootStrapLanguageTest(args *languageArgs) *language {
@@ -62,11 +56,6 @@ func bootStrapLanguageTest(args *languageArgs) *language {
 	env.On("Pwd").Return(cwd)
 	env.On("Home").Return(home)
 
-	cache := &cache_.Cache{}
-	cache.On("Get", mock_.Anything).Return("", false)
-	cache.On("Set", mock_.Anything, mock_.Anything, mock_.Anything).Return(nil)
-	env.On("Cache").Return(cache)
-
 	if args.properties == nil {
 		args.properties = properties.Map{}
 	}
@@ -549,11 +538,6 @@ func getMockedLanguageEnv(params *mockedLanguageParams) (*mock.Environment, prop
 	env.On("Pwd").Return("/usr/home/project")
 	env.On("Home").Return("/usr/home")
 
-	cache := &cache_.Cache{}
-	cache.On("Get", mock_.Anything).Return("", false)
-	cache.On("Set", mock_.Anything, mock_.Anything, mock_.Anything).Return(nil)
-	env.On("Cache").Return(cache)
-
 	props := properties.Map{
 		properties.FetchVersion: true,
 	}
