@@ -6,12 +6,10 @@ import (
 )
 
 type SystemInfo struct {
-	props properties.Properties
-	env   runtime.Environment
-
-	Precision int
+	base
 
 	runtime.SystemInfo
+	Precision int
 }
 
 const (
@@ -24,19 +22,18 @@ func (s *SystemInfo) Template() string {
 }
 
 func (s *SystemInfo) Enabled() bool {
+	s.Precision = s.props.GetInt(Precision, 2)
+
+	sysInfo, err := s.env.SystemInfo()
+	if err != nil {
+		return false
+	}
+
+	s.SystemInfo = *sysInfo
+
 	if s.PhysicalPercentUsed == 0 && s.SwapPercentUsed == 0 {
 		return false
 	}
+
 	return true
 }
-
-func (s *SystemInfo) Init(props properties.Properties, env runtime.Environment) {
-	s.props = props
-	s.env = env
-	s.Precision = s.props.GetInt(Precision, 2)
-	sysInfo, err := env.SystemInfo()
-	if err != nil {
-		return
-	}
-	s.SystemInfo = *sysInfo
-}
